@@ -4,7 +4,8 @@
 using namespace Rcpp;
 
 // [[Rcpp::export]]
-List mfwrapper(NumericMatrix xi, IntegerVector Lv, NumericVector Eps){
+List mfwrapper(NumericMatrix xi, IntegerVector freq, NumericMatrix qJ,
+               IntegerVector Lv, NumericVector Eps){
   
   int n = xi.nrow();
   int m = xi.ncol();
@@ -16,14 +17,18 @@ List mfwrapper(NumericMatrix xi, IntegerVector Lv, NumericVector Eps){
       sv[k].push_back(xi(k,i));
   }
   
+  std::vector<int> frq(n);
+  for(int k=0; k<n; k++)
+    frq[k] = freq(k);
+  
   int mL=L.size();
   std::vector<std::vector<double> > hp(mL);
   std::vector<std::vector<std::vector<double> > > Jp(mL);
   
   double eps = Eps[0];
-  
+  double lkl = 0;
   double lnz = 0;
-  invC(sv, L, lnz, hp, Jp, eps);
+  invC(sv, frq, L, lkl, lnz, hp, Jp, eps);
   
   std::vector<std::vector<double> > h(m);
   std::vector<std::vector<std::vector<double> > > J(m);
@@ -33,11 +38,15 @@ List mfwrapper(NumericMatrix xi, IntegerVector Lv, NumericVector Eps){
     J[i].resize(m);
     h[i]=hp[ic];
     int jc=0;
-    for(int j=0; j<m; j++)
-      J[i][j]=Jp[ic][jc++];
+    for(int j=0; j<m; j++){
+      J[i][j] = Jp[ic][jc++];
+      if(!qJ(i,j))
+        std::fill(J[i][j].begin(), J[i][j].end(), 0.0); // non-interacting pairs
+    }
     ic++;
   }
     
-  List x = List::create(Named("h") = h, Named("J") = J, Named("lz") = lnz);
+  List x = List::create(Named("h") = h, Named("J") = J, Named("lkh") = lkl, 
+                        Named("lz")= lnz);
   return x;
 }
